@@ -9,28 +9,40 @@ summary_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
+    time = NULL,
+    report_start = function() {
+      self$time <- proc.time()["elapsed"]
+      cli_df_header(progress_init(path = tempfile())$cli_data())
+    },
+    report_progress = function(progress) {
+      cli_df_body(progress$cli_data())
+    },
     report_error = function(error) {
     },
-    report_start = function() {
-      cli_df_header(progress_init()$cli_data())
-    },
     report_started = function(target = NULL, progress) {
-      cli_df_body(progress$cli_data())
+      self$report_progress(progress)
     },
     report_built = function(target = NULL, progress) {
-      cli_df_body(progress$cli_data())
+      self$report_progress(progress)
     },
     report_skipped = function(target = NULL, progress) {
-      cli_df_body(progress$cli_data())
+      time <- proc.time()["elapsed"]
+      # nocov start
+      # Covered in tests/interactive/test-reporter.R.
+      if (time - self$time > 0.25) {
+        self$report_progress(progress)
+        self$time <- time
+      }
+      # nocov end
     },
     report_errored = function(target = NULL, progress) {
-      cli_df_body(progress$cli_data())
+      self$report_progress(progress)
     },
     report_canceled = function(target = NULL, progress) {
-      cli_df_body(progress$cli_data())
+      self$report_progress(progress)
     },
     report_end = function(progress) {
-      cli_df_body(progress$cli_data())
+      self$report_progress(progress)
       message("")
     }
   )
