@@ -4,7 +4,8 @@
 #' @family pipeline
 #' @description This function is like [tar_make()] except that targets
 #'   run in parallel with transient `future` workers. It requires
-#'   that you declare your `future::plan()` inside the `_targets.R` script.
+#'   that you declare your `future::plan()` inside the
+#'   target script file (default: `_targets.R`).
 #'   `future` is not a strict dependency of `targets`,
 #'   so you must install `future` yourself.
 #' @details To configure `tar_make_future()` with a computing cluster,
@@ -16,7 +17,7 @@
 #' @param workers Positive integer, maximum number of transient
 #'   `future` workers allowed to run at any given time.
 #' @examples
-#' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
+#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) {
 #' tar_dir({ # tar_dir() runs code from a temporary directory.
 #' tar_script({
 #'   future::plan(future::multisession, workers = 2)
@@ -30,18 +31,29 @@
 #' }
 tar_make_future <- function(
   names = NULL,
-  reporter = Sys.getenv("TAR_MAKE_REPORTER", unset = "verbose"),
-  workers = 1L,
+  shortcut = targets::tar_config_get("shortcut"),
+  reporter = targets::tar_config_get("reporter_make"),
+  workers = targets::tar_config_get("workers"),
   callr_function = callr::r,
-  callr_arguments = targets::callr_args_default(callr_function, reporter)
+  callr_arguments = targets::callr_args_default(callr_function, reporter),
+  envir = parent.frame(),
+  script = targets::tar_config_get("script"),
+  store = targets::tar_config_get("store")
 ) {
-  assert_package("future")
-  assert_script()
-  assert_flag(reporter, choices = tar_make_reporters())
-  assert_callr_function(callr_function)
-  assert_list(callr_arguments, "callr_arguments mut be a list.")
+  force(envir)
+  tar_assert_package("future")
+  tar_assert_scalar(shortcut)
+  tar_assert_lgl(shortcut)
+  tar_assert_flag(reporter, tar_make_reporters())
+  tar_assert_scalar(workers)
+  tar_assert_dbl(workers)
+  tar_assert_ge(workers, 1)
+  tar_assert_callr_function(callr_function)
+  tar_assert_list(callr_arguments)
   targets_arguments <- list(
+    path_store = store,
     names_quosure = rlang::enquo(names),
+    shortcut = shortcut,
     reporter = reporter,
     workers = workers
   )
@@ -49,16 +61,27 @@ tar_make_future <- function(
     targets_function = tar_make_future_inner,
     targets_arguments = targets_arguments,
     callr_function = callr_function,
-    callr_arguments = callr_arguments
+    callr_arguments = callr_arguments,
+    envir = envir,
+    script = script
   )
   invisible(out)
 }
 
-tar_make_future_inner <- function(pipeline, names_quosure, reporter, workers) {
-  names <- eval_tidyselect(names_quosure, pipeline_get_names(pipeline))
+tar_make_future_inner <- function(
+  pipeline,
+  path_store,
+  names_quosure,
+  shortcut,
+  reporter,
+  workers
+) {
+  names <- tar_tidyselect_eval(names_quosure, pipeline_get_names(pipeline))
   future_init(
     pipeline = pipeline,
+    meta_init(path_store = path_store),
     names = names,
+    shortcut = shortcut,
     queue = "parallel",
     reporter = reporter,
     workers = workers
