@@ -14,14 +14,15 @@
 #'   * `branches`: number of dynamic branches of a pattern. 0 for non-patterns.
 #'   * `progress`: the most recent progress update of that target.
 #'     Could be `"started"`, `"built"`, `"canceled"`, or `"errored"`.
+#' @inheritParams tar_validate
 #' @param names Optional, names of the targets. If supplied, `tar_progress()`
 #'   only returns progress information on these targets.
-#'   You can supply symbols, a character vector,
-#'   or `tidyselect` helpers like [starts_with()].
+#'   You can supply symbols
+#'   or `tidyselect` helpers like [all_of()] and [starts_with()].
 #' @param fields Optional, names of progress data columns to read.
 #'   Set to `NULL` to read all fields.
 #' @examples
-#' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
+#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) {
 #' tar_dir({ # tar_dir() runs code from a temporary directory.
 #' tar_script({
 #'   list(
@@ -31,17 +32,22 @@
 #' }, ask = FALSE)
 #' tar_make()
 #' tar_progress()
-#' tar_progress(starts_with("y_"))
+#' tar_progress(starts_with("y_")) # see also all_of()
 #' })
 #' }
-tar_progress <- function(names = NULL, fields = "progress") {
-  assert_store()
-  assert_path(path_progress())
-  out <- tibble::as_tibble(progress_init()$database$read_condensed_data())
+tar_progress <- function(
+  names = NULL,
+  fields = "progress",
+  store = targets::tar_config_get("store")
+) {
+  tar_assert_path(path_progress(path_store = store))
+  progress <- progress_init(path_store = store)
+  out <- tibble::as_tibble(progress$database$read_condensed_data())
   names_quosure <- rlang::enquo(names)
   fields_quosure <- rlang::enquo(fields)
-  names <- eval_tidyselect(names_quosure, out$name)
-  fields <- eval_tidyselect(fields_quosure, colnames(out)) %|||% colnames(out)
+  names <- tar_tidyselect_eval(names_quosure, out$name)
+  fields <- tar_tidyselect_eval(fields_quosure, colnames(out)) %|||%
+    colnames(out)
   if (!is.null(names)) {
     out <- out[match(names, out$name),, drop = FALSE] # nolint
   }
