@@ -9,15 +9,18 @@ tar_test("aws_file format file gets stored", {
     aws.s3::delete_object(object = "_targets/objects", bucket = bucket_name)
     aws.s3::delete_object(object = "_targets", bucket = bucket_name)
     aws.s3::delete_bucket(bucket = bucket_name)
-    expect_false(aws.s3::bucket_exists(bucket = bucket_name))
   })
   aws.s3::put_bucket(bucket = bucket_name)
   expr <- quote({
-    tar_option_set(resources = list(bucket = !!bucket_name))
-    write_local_file <- function(lines) {
-      writeLines(lines, "example_aws_file.txt")
-      "example_aws_file.txt"
-    }
+    tar_option_set(resources = tar_resources(
+      aws = tar_resources_aws(bucket = !!bucket_name)
+    ))
+    evalq(
+      write_local_file <- function(lines) {
+        writeLines(lines, "example_aws_file.txt")
+        "example_aws_file.txt"
+      }, envir = tar_option_get("envir")
+    )
     list(
       tar_target(x, write_local_file("x_lines"), format = "aws_file"),
       tar_target(y, readLines(x))
@@ -25,7 +28,7 @@ tar_test("aws_file format file gets stored", {
   })
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-  tar_make(callr_function = NULL)
+  tar_make(callr_function = NULL, envir = tar_option_get("envir"))
   expect_true(
     aws.s3::object_exists(bucket = bucket_name, object = "_targets/objects/x")
   )
@@ -33,10 +36,12 @@ tar_test("aws_file format file gets stored", {
   expect_equal(tar_read(y), "x_lines")
   expect_equal(length(list.files("_targets/scratch/")), 0L)
   expect_false(file.exists("_targets/scratch/x"))
+  expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("_targets/scratch/")), 1L)
-  expect_true(file.exists("_targets/scratch/x"))
-  expect_equal(readLines(path), "x_lines")
+  expect_equal(length(list.files("_targets/scratch/")), 0L)
+  expect_false(file.exists("_targets/scratch/x"))
+  expect_true(file.exists("example_aws_file.txt"))
+  expect_equal(readLines("example_aws_file.txt"), "x_lines")
   tmp <- tempfile()
   aws.s3::save_object(
     object = "_targets/objects/x",
@@ -58,13 +63,17 @@ tar_test("aws_file format invalidation", {
     aws.s3::put_bucket(bucket = bucket_name)
     expr <- quote({
       tar_option_set(
-        resources = list(bucket = !!bucket_name),
+        resources = tar_resources(
+          aws = tar_resources_aws(bucket = !!bucket_name)
+        ),
         memory = !!memory
       )
-      write_local_file <- function(lines) {
-        writeLines(lines, "example_aws_file.txt")
-        "example_aws_file.txt"
-      }
+      evalq(
+        write_local_file <- function(lines) {
+          writeLines(lines, "example_aws_file.txt")
+          "example_aws_file.txt"
+        }, envir = tar_option_get("envir")
+      )
       list(
         tar_target(x, write_local_file("x_lines"), format = "aws_file"),
         tar_target(y, readLines(x))
@@ -72,20 +81,26 @@ tar_test("aws_file format invalidation", {
     })
     expr <- tar_tidy_eval(expr, environment(), TRUE)
     eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-    tar_make(callr_function = NULL)
+    tar_make(callr_function = NULL, envir = tar_option_get("envir"))
     expect_equal(tar_progress(x)$progress, "built")
     expect_equal(tar_progress(y)$progress, "built")
     tar_make(callr_function = NULL)
-    expect_equal(nrow(tar_progress()), 0L)
+    progress <- tar_progress()
+    progress <- progress[progress$progress != "skipped", ]
+    expect_equal(nrow(progress), 0L)
     expr <- quote({
       tar_option_set(
-        resources = list(bucket = !!bucket_name),
+        resources = tar_resources(
+          aws = tar_resources_aws(bucket = !!bucket_name)
+        ),
         memory = !!memory
       )
-      write_local_file <- function(lines) {
-        writeLines(lines, "example_aws_file.txt")
-        "example_aws_file.txt"
-      }
+      evalq(
+        write_local_file <- function(lines) {
+          writeLines(lines, "example_aws_file.txt")
+          "example_aws_file.txt"
+        }, envir = tar_option_get("envir")
+      )
       list(
         tar_target(x, write_local_file("x_lines2"), format = "aws_file"),
         tar_target(y, readLines(x))
@@ -93,7 +108,7 @@ tar_test("aws_file format invalidation", {
     })
     expr <- tar_tidy_eval(expr, environment(), TRUE)
     eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-    tar_make(callr_function = NULL)
+    tar_make(callr_function = NULL, envir = tar_option_get("envir"))
     expect_equal(tar_progress(x)$progress, "built")
     expect_equal(tar_progress(y)$progress, "built")
     expect_equal(tar_read(y), "x_lines2")
@@ -107,8 +122,6 @@ tar_test("aws_file format invalidation", {
   }
 })
 
-# Run this one interactively and check that the object prefixes
-# (pseudo-folders) are correct.
 tar_test("aws_file format with a custom data store", {
   skip_if_no_aws()
   writeLines("store: custom_targets_store", "_targets.yaml")
@@ -122,15 +135,18 @@ tar_test("aws_file format with a custom data store", {
     aws.s3::delete_object(object = "_targets/objects", bucket = bucket_name)
     aws.s3::delete_object(object = "_targets", bucket = bucket_name)
     aws.s3::delete_bucket(bucket = bucket_name)
-    expect_false(aws.s3::bucket_exists(bucket = bucket_name))
   })
   aws.s3::put_bucket(bucket = bucket_name)
   expr <- quote({
-    tar_option_set(resources = list(bucket = !!bucket_name))
-    write_local_file <- function(lines) {
-      writeLines(lines, "example_aws_file.txt")
-      "example_aws_file.txt"
-    }
+    tar_option_set(resources = tar_resources(
+      aws = tar_resources_aws(bucket = !!bucket_name)
+    ))
+    evalq(
+      write_local_file <- function(lines) {
+        writeLines(lines, "example_aws_file.txt")
+        "example_aws_file.txt"
+      }, envir = tar_option_get("envir")
+    )
     list(
       tar_target(x, write_local_file("x_lines"), format = "aws_file"),
       tar_target(y, readLines(x))
@@ -138,7 +154,7 @@ tar_test("aws_file format with a custom data store", {
   })
   expr <- tar_tidy_eval(expr, environment(), TRUE)
   eval(as.call(list(`tar_script`, expr, ask = FALSE)))
-  tar_make(callr_function = NULL)
+  tar_make(callr_function = NULL, envir = tar_option_get("envir"))
   expect_true(file.exists("custom_targets_store"))
   expect_false(file.exists(path_store_default()))
   expect_true(
@@ -146,9 +162,11 @@ tar_test("aws_file format with a custom data store", {
   )
   expect_equal(tar_read(y), "x_lines")
   expect_equal(length(list.files("custom_targets_store/scratch/")), 0L)
+  expect_false(file.exists("example_aws_file.txt"))
   path <- tar_read(x)
-  expect_equal(length(list.files("custom_targets_store/scratch/")), 1L)
-  expect_equal(readLines(path), "x_lines")
+  expect_equal(length(list.files("custom_targets_store/scratch/")), 0L)
+  expect_true(file.exists("example_aws_file.txt"))
+  expect_equal(readLines("example_aws_file.txt"), "x_lines")
   tmp <- tempfile()
   aws.s3::save_object(
     object = "_targets/objects/x",
