@@ -23,7 +23,7 @@ tar_test("dynamic urls work", {
   )
   expect_equal(tar_progress(fields = NULL), exp)
   tar_make(callr_function = NULL)
-  expect_equal(nrow(tar_progress()), 0)
+  expect_equal(tar_progress()$progress, "skipped")
   meta <- tar_meta(abc)
   expect_equal(nchar(meta$data), 16)
   out <- meta$path[[1]]
@@ -31,6 +31,42 @@ tar_test("dynamic urls work", {
   expect_equal(out, exp)
   expect_equal(tar_read(abc), exp)
   expect_false(file.exists(file.path("_targets", "objects", "abc")))
+  expect_true(inherits(tar_timestamp(abc), "POSIXct"))
+  expect_gt(tar_timestamp(abc), tar_timestamp(nope))
+})
+
+tar_test("dynamic urls in dynamic branches work", {
+  skip_on_cran()
+  skip_if_not_installed("curl")
+  skip_if_offline()
+  url <- "https://httpbin.org/etag/test"
+  skip_if(!url_exists(url))
+  tar_script({
+    list(
+      tar_target(x, 1),
+      tar_target(
+        abc,
+        "https://httpbin.org/etag/test",
+        format = "url",
+        pattern = map(x)
+      )
+    )
+  })
+  tar_make(callr_function = NULL)
+  branch <- tar_branch_names(abc, 1)
+  expect_equal(tar_progress(fields = NULL)$progress, rep("built", 3))
+  tar_make(callr_function = NULL)
+  expect_equal(tar_progress(fields = NULL)$progress, rep("skipped", 3))
+  meta <- tar_meta()
+  meta <- meta[meta$name == branch, ]
+  expect_equal(nchar(meta$data), 16)
+  out <- meta$path[[1]]
+  expect_equal(out, url)
+  expect_equal(tar_read_raw(branch), url)
+  expect_false(file.exists(file.path("_targets", "objects", "abc")))
+  expect_false(file.exists(file.path("_targets", "objects", branch)))
+  expect_true(inherits(tar_timestamp_raw(branch), "POSIXct"))
+  expect_gt(tar_timestamp_raw(branch), tar_timestamp(nope))
 })
 
 tar_test("dynamic urls work from a custom data store", {
@@ -62,7 +98,7 @@ tar_test("dynamic urls work from a custom data store", {
   )
   expect_equal(tar_progress(fields = NULL), exp)
   tar_make(callr_function = NULL)
-  expect_equal(nrow(tar_progress()), 0)
+  expect_equal(tar_progress()$progress, "skipped")
   meta <- tar_meta(abc)
   expect_equal(nchar(meta$data), 16)
   out <- meta$path[[1]]
@@ -80,7 +116,7 @@ tar_test("dynamic urls work from a custom data store", {
   expect_true(file.exists(path_store_default()))
   expect_equal(tar_outdated(callr_function = NULL), character(0))
   tar_make(callr_function = NULL)
-  expect_equal(nrow(tar_progress()), 0)
+  expect_equal(unique(tar_progress()$progress), "skipped")
 })
 
 tar_test("tar_condition_run error on bad URL", {
@@ -91,7 +127,7 @@ tar_test("tar_condition_run error on bad URL", {
   expect_error(tar_make(callr_function = NULL), class = "tar_condition_run")
 })
 
-tar_test("custom handle can be supplied without error", {
+tar_test("custom handle without error (unstructured resources)", {
   skip_on_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
@@ -107,7 +143,16 @@ tar_test("custom handle can be supplied without error", {
       )
     )
   })
-  tar_make(callr_function = NULL)
+  expect_warning(
+    tar_target(
+      abc,
+      rep("https://httpbin.org/etag/test", 2),
+      format = "url",
+      resources = list(handle = curl::new_handle())
+    ),
+    class = "tar_condition_deprecate"
+  )
+  suppressWarnings(tar_make(callr_function = NULL))
   expect_equal(tar_read(abc), rep("https://httpbin.org/etag/test", 2))
   expect_false(file.exists(file.path("_targets", "objects", "abc")))
 })
@@ -126,20 +171,62 @@ tar_test("dynamic urls must return characters", {
   expect_error(local$run(), class = "tar_condition_validate")
 })
 
-tar_test("url target store gets custom curl handle", {
+tar_test("url target gets custom curl handle (structured resources)", {
   skip_on_cran()
   skip_if_not_installed("curl")
-  x <- target_init(
+  x <- tar_target_raw(
     name = "abc",
-    expr = quote(list(list("illegal"))),
+    command = quote(list(list("illegal"))),
     format = "url",
-    resources = list(handle = curl::new_handle())
+    resources = tar_resources(
+      url = tar_resources_url(handle = curl::new_handle())
+    )
+  )
+  handle <- x$store$resources$url$handle
+  expect_true(inherits(handle, "curl_handle"))
+})
+
+tar_test("url target gets custom curl handle (unstructured resources)", {
+  skip_on_cran()
+  skip_if_not_installed("curl")
+  expect_warning(
+    x <- tar_target_raw(
+      name = "abc",
+      command = quote(list(list("illegal"))),
+      format = "url",
+      resources = list(handle = curl::new_handle())
+    ),
+    class = "tar_condition_deprecate"
   )
   handle <- x$store$resources$handle
   expect_true(inherits(handle, "curl_handle"))
 })
 
-tar_test("bad curl handle throws an error", {
+tar_test("bad curl handle throws an error (structrued resources)", {
+  skip_on_cran()
+  skip_if_not_installed("curl")
+  skip_if_offline()
+  url <- "https://httpbin.org/etag/test"
+  skip_if(!url_exists(url))
+  tar_script({
+    list(
+      tar_target(
+        abc,
+        rep("https://httpbin.org/etag/test", 2),
+        format = "url",
+        resources = tar_resources(
+          url = tar_resources_url(handle = "invalid")
+        )
+      )
+    )
+  })
+  expect_error(
+    tar_make(callr_function = NULL),
+    class = "tar_condition_validate"
+  )
+})
+
+tar_test("bad curl handle throws an error (unstructrued resources)", {
   skip_on_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
@@ -155,9 +242,20 @@ tar_test("bad curl handle throws an error", {
       )
     )
   })
-  expect_error(
-    tar_make(callr_function = NULL),
-    class = "tar_condition_validate"
+  expect_warning(
+    tar_target(
+      abc,
+      rep("https://httpbin.org/etag/test", 2),
+      format = "url",
+      resources = list(handle = "invalid")
+    ),
+    class = "tar_condition_deprecate"
+  )
+  suppressWarnings(
+    expect_error(
+      tar_make(callr_function = NULL),
+      class = "tar_condition_validate"
+    )
   )
 })
 
@@ -175,7 +273,10 @@ tar_test("store_row_path()", {
 tar_test("store_path_from_record()", {
   store <- tar_target(x, "x_value", format = "url")$store
   record <- record_init(path = "path", format = "url")
-  expect_equal(store_path_from_record(store, record), "path")
+  expect_equal(
+    store_path_from_record(store, record, path_store_default()),
+    "path"
+  )
 })
 
 tar_test("url packages", {
